@@ -6,6 +6,11 @@
 #include "mount.h"
 #include "rmdir.h"
 #include "umount.h"
+#include "cat.h"
+#include "mkfifo.h"
+#include "cp.h"
+#include "hostname.h"
+#include "sh.h"
 
 int (*(commands_exec[256]))()={
 			ls_main,
@@ -16,6 +21,11 @@ int (*(commands_exec[256]))()={
 			mount_main,
 			rmdir_main,
 			umount_main,
+			cat_main,
+			mkfifo_main,
+			cp_main,
+			hostname_main,
+			sh_main,
 			NULL
 };
 
@@ -28,5 +38,10 @@ char *commands_name[256]={
 			"mount",
 			"rmdir",
 			"umount",
+			"cat",
+			"mkfifo",
+			"cp",
+			"hostname",
+			"sh",
 			NULL
 };
