@@ -8,6 +8,7 @@
 int rmdir_main (int argc, char **argv) {
 	char option_recurse=0;
 	int i;
+	int error_code=0;
 
 	while (1) {
 		if ((argc-option_recurse)==1) {
@@ -20,11 +21,14 @@ int rmdir_main (int argc, char **argv) {
 			break;
 		}
 	}
-
-	for (i=option_recurse;i<(argc-1);i++) {
-/* TODO: Make it actually call rmdir(2) here. */
-		printf("%s\n",argv[i]);
+/* TODO: Make Recursion actually work. */
+	for (i=option_recurse+1;i<argc;i++) {
+		if (rmdir(argv[i])<0) {
+			write(STDERR_FILENO, "rmdir: ", 7);
+			perror(argv[i]);
+			error_code=-1;
+		}
 	}
 
-	return(0);	
+	return(error_code);
 }
